==> tfx_bsl-0.21.4-cp27-cp27m-macosx_10_9_x86_64.whl: tfx_bsl/tfxio/raw_tf_record.py <==
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""TFXIO implementations for raw TF Record."""

from __future__ import absolute_import
from __future__ import division
# Standard __future__ imports
from __future__ import print_function

import apache_beam as beam
import pyarrow as pa
import tensorflow as tf  # pylint: disable=g-explicit-tensorflow-version-import
from tfx_bsl.tfxio import record_based_tfxio
from tfx_bsl.tfxio import tensor_adapter
from tfx_bsl.tfxio import tfxio
from tfx_bsl.types_compat import List, Optional, Text

from tensorflow_metadata.proto.v0 import schema_pb2


class _RawRecordTFXIO(record_based_tfxio.RecordBasedTFXIO):
  """Base class for raw record TFXIO implementations.

  A raw record TFXIO decodes a record based on-disk format into an
  RecordBatches of one column that contains the raw records. Its TensorAdapter
  converts one such RecordBatch into a dense string tensor that contains
  the raw records.

  `raw_record_column_name` determines the name of the raw record column and
  the tensor.
  """

  def __init__(self, raw_record_column_name      ):
    assert raw_record_column_name is not None
    super(_RawRecordTFXIO, self).__init__(raw_record_column_name)

  def SupportAttachingRawRecords(self)        :
    return True

  def RawRecordToRecordBatch(self,
                             batch_size                = None
                            )                   :

    @beam.ptransform_fn
    @beam.typehints.with_input_types(beam.Pipeline)
    @beam.typehints.with_output_types(pa.RecordBatch)
    def _PTransformFn(raw_record_pcoll                         ):
      return (raw_record_pcoll
              | 'Batch' >> beam.BatchElements(
                  **record_based_tfxio.GetBatchElementsKwargs(batch_size))
              | 'ToRecordBatch' >> beam.Map(_BatchedRecordsToArrow,
                                            self.raw_record_column_name))

    return _PTransformFn()  # pylint: disable=no-value-for-parameter

  def _ArrowSchemaNoRawRecordColumn(self)             :
    # The only column is the raw record column.
    return pa.schema([])

  def TensorFlowDataset(self)                   :
    raise NotImplementedError

  def TensorRepresentations(self)                                        :
    return {
        self.raw_record_column_name:
            schema_pb2.TensorRepresentation(
                dense_tensor=schema_pb2.TensorRepresentation.DenseTensor(
                    column_name=self.raw_record_column_name,
                    shape=schema_pb2.FixedShape(),  # scalar
                ))
    }

  def _ProjectImpl(self, tensor_names            )               :
    assert (len(tensor_names) == 1 and
            tensor_names[0] == self.raw_record_column_name)
    return self


def _BatchedRecordsToArrow(records             ,
                           raw_record_column_name)                  :
  raw_record_column = record_based_tfxio.CreateRawRecordColumn(records)
  return pa.RecordBatch.from_arrays(
      [raw_record_column], [raw_record_column_name])


class RawTfRecordTFXIO(_RawRecordTFXIO):
  """Raw record TFXIO for TFRecord format."""

  def __init__(self, file_pattern      , raw_record_column_name      ):
    super(RawTfRecordTFXIO, self).__init__(raw_record_column_name)
    self._file_pattern = file_pattern

  def RawRecordBeamSource(self)                   :
    @beam.ptransform_fn
    @beam.typehints.with_input_types(beam.Pipeline)
    @beam.typehints.with_output_types(bytes)
    def _PTransformFn(pipeline                         ):
      return pipeline | 'ReadFromTFRecord' >> beam.io.ReadFromTFRecord(
          self._file_pattern,
          coder=beam.coders.BytesCoder(),
          # TODO(b/114938612): Eventually remove this override.
          validate=False)

    return _PTransformFn()  # pylint: disable=no-value-for-parameter

==> tfx_bsl-0.22.0-cp27-cp27m-macosx_10_9_x86_64.whl: tfx_bsl/tfxio/raw_tf_record.py <==
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""TFXIO implementations for raw TF Record."""

from __future__ import absolute_import
from __future__ import division
# Standard __future__ imports
from __future__ import print_function

from absl import logging
import apache_beam as beam
import pyarrow as pa
import tensorflow as tf  # pylint: disable=g-explicit-tensorflow-version-import
from tfx_bsl.coders import batch_util
from tfx_bsl.tfxio import record_based_tfxio
from tfx_bsl.tfxio import tensor_adapter
from tfx_bsl.tfxio import tfxio
from tfx_bsl.types_compat import List, Optional, Text

from tensorflow_metadata.proto.v0 import schema_pb2


class _RawRecordTFXIO(record_based_tfxio.RecordBasedTFXIO):
  """Base class for raw record TFXIO implementations.

  A raw record TFXIO decodes a record based on-disk format into an
  RecordBatches of one column that contains the raw records. Its TensorAdapter
  converts one such RecordBatch into a dense string tensor that contains
  the raw records.

  `raw_record_column_name` determines the name of the raw record column and
  the tensor.
  """

  def __init__(self, raw_record_column_name      ,
               telemetry_descriptors                      ,
               physical_format      ):
    assert raw_record_column_name is not None
    super(_RawRecordTFXIO, self).__init__(
        raw_record_column_name=raw_record_column_name,
        telemetry_descriptors=telemetry_descriptors,
        logical_format="bytes",
        physical_format=physical_format)
    if self._can_produce_large_types:
      logging.info("We decided to produce LargeList and LargeBinary types.")

  def SupportAttachingRawRecords(self)        :
    return True

  def RawRecordToRecordBatchInternal(self,
                                     batch_size                = None
                                    )                   :

    @beam.typehints.with_input_types(beam.Pipeline)
    @beam.typehints.with_output_types(pa.RecordBatch)
    def _PTransformFn(raw_record_pcoll                         ):
      return (raw_record_pcoll
              | "Batch" >> beam.BatchElements(
                  **batch_util.GetBatchElementsKwargs(batch_size))
              | "ToRecordBatch" >>
              beam.Map(_BatchedRecordsToArrow, self.raw_record_column_name,
                       self._can_produce_large_types))

    return beam.ptransform_fn(_PTransformFn)()

  def _ArrowSchemaNoRawRecordColumn(self)             :
    # The only column is the raw record column.
    return pa.schema([])

  def TensorFlowDataset(self)                   :
    raise NotImplementedError

  def TensorRepresentations(self)                                        :
    return {
        self.raw_record_column_name:
            schema_pb2.TensorRepresentation(
                dense_tensor=schema_pb2.TensorRepresentation.DenseTensor(
                    column_name=self.raw_record_column_name,
                    shape=schema_pb2.FixedShape(),  # scalar
                ))
    }

  def _ProjectImpl(self, tensor_names            )               :
    assert (not tensor_names or
            (len(tensor_names) == 1
             and tensor_names[0] == self.raw_record_column_name)), (
                 str(tensor_names))
    return self


def _BatchedRecordsToArrow(records             ,
                           raw_record_column_name      ,
                           should_produce_large_types      )                  :
  raw_record_column = record_based_tfxio.CreateRawRecordColumn(
      records, should_produce_large_types)
  return pa.RecordBatch.from_arrays(
      [raw_record_column], [raw_record_column_name])


class RawTfRecordTFXIO(_RawRecordTFXIO):
  """Raw record TFXIO for TFRecord format."""

  def __init__(self, file_pattern      , raw_record_column_name      ,
               telemetry_descriptors                       = None):
    super(RawTfRecordTFXIO, self).__init__(
        telemetry_descriptors=telemetry_descriptors,
        physical_format="tfrecords_gzip",
        raw_record_column_name=raw_record_column_name)
    self._file_pattern = file_pattern

  def RawRecordBeamSourceInternal(self)                   :
    @beam.typehints.with_input_types(beam.Pipeline)
    @beam.typehints.with_output_types(bytes)
    def _PTransformFn(pipeline                         ):
      return pipeline | "ReadFromTFRecord" >> beam.io.ReadFromTFRecord(
          self._file_pattern,
          coder=beam.coders.BytesCoder(),
          # TODO(b/114938612): Eventually remove this override.
          validate=False)

    return beam.ptransform_fn(_PTransformFn)()
